
clear *
cap log close
set more off
set matsize 4000

cd "C:\Users\56570tpe\Dropbox (Erasmus Universiteit Rotterdam)\work\published papers\2021 Economist - seasonal HA\Replication files"

log using homeadvantage.log, replace

*******************************************PART 1 MERGING DATA SETS AND CREATE SEASONAL SAMPLE********************************************

*******************************merging dataset***************************

use Englandgames.dta, clear

merge m:1 year id using Englandfinances.dta
tab _merge
drop if _merge==2
rename _merge finmerge
save Englandgamelevel.dta, replace

merge m:1 manid using Englandmanagers.dta
tab _merge
drop if _merge==2
rename _merge manmerge

sum manmerge finmerge
drop manmerge finmerge

save Englandgamelevel.dta, replace

************************creating some seasonal measures**************************

use Englandgamelevel.dta, clear

gen points=3*win+draw
gen gd=sc-op_sc
sum win draw loss points sc op_sc gd if home==1

***Split results at home and away
gen hhomegopro=home*sc
gen hhomegoag=home*op_sc
gen hawaygopro=(1-home)*sc
gen hawaygoag=(1-home)*op_sc

gen hhomewin=home*win
gen hhomeloss=home*loss
gen hhomedraw=home*draw
gen hawaywin=(1-home)*win
gen hawayloss=(1-home)*loss
gen hawaydraw=(1-home)*draw

gen homeatt=home*attendance
gen awayatt=(1-home)*attendance

bysort year id: egen homegopro=total(hhomegopro)
bysort year id: egen homegoag=total(hhomegoag)
bysort year id: egen awaygopro=total(hawaygopro)
bysort year id: egen awaygoag=total(hawaygoag)
bysort year id: egen homewin=total(hhomewin)
bysort year id: egen homeloss=total(hhomeloss)
bysort year id: egen homedraw=total(hhomedraw)
bysort year id: egen awaywin=total(hawaywin)
bysort year id: egen awayloss=total(hawayloss)
bysort year id: egen awaydraw=total(hawaydraw)

bysort year id: egen avhomeatt=mean(homeatt)
bysort year id: egen avawayatt=mean(awayatt)

gen teams=played/2+1

***make dummies for coaches
sum manidfe
bysort year id: egen mmanid=mean(manidfe)
gen yearmanager=manager 	if mmanid==manidfe
gen yearmanid=manidfe 		if mmanid==manidfe
drop manager
drop manidfe
rename yearmanid manidfe
rename yearmanager manager
sort manidfe year
replace manager = manager[_n-1] if manidfe==manidfe[_n-1]

sum manidfe

***collapse to season level

collapse id homegopro homegoag awaygopro awaygoag homewin homeloss homedraw awaywin awayloss awaydraw division wage rev avhomeatt avawayatt avatt ///
stadcap newstadyear newstaddum rank played seasonpoints teams manidfe, by(year team stadname manager)

rename seasonpoints points

corr avatt avhomeatt avawayatt

bysort year div: egen mdavatt=mean(avatt)
bysort year div: egen mdwage=mean(wage)
bysort year div: egen mdrev=mean(rev)

bysort year: egen myavatt=mean(avatt)
bysort year: egen mwage=mean(wage)
bysort year: egen mrev=mean(rev)

gen relatt=log(avatt/mdavatt)
gen relawayatt=log(avawayatt/mdavatt)

gen relwage=log(wage/mdwage)
gen relrev=log(rev/mdrev)

gen logwage=wage/1000000

gen trend=year-1974
gen stadage=year-newstadyear

*artificial pitch dummy
gen AP=(id==77)*(year>=1982)*(year<=1988)+(id==54)*(year>=1986)*(year<=1990)+(id==76)*(year>=1987)*(year<=1991)+(id==70)*(year>=1987)*(year<=1991)


***************Calculate seasonal quality and home advantage*************************

gen HGD=homegopro-homegoag
gen AGD=awaygopro-awaygoag
gen HWD=homewin-homeloss
gen AWD=awaywin-awayloss
gen HPD=(homewin-homeloss)*3
gen APD=(awaywin-awayloss)*3

bysort division year: egen totalHGD=total(HGD)
bysort division year: egen totalHWD=total(HWD)
bysort division year: egen totalHPD=total(HPD)

gen H_godif = totalHGD/(teams-1)
gen H_win = totalHWD/(teams-1)
gen H_points = totalHPD/(teams-1)

gen HA_godif = (HGD-AGD-H_godif)/(teams-2)
gen HA_win = (HWD-AWD-H_win)/(teams-2)
gen HA_points = (HPD-APD-H_points)/(teams-2)

gen AB_godif = (HGD - (teams-1)*HA_godif)/teams
gen AB_win = (HWD - (teams-1)*HA_win)/teams
gen AB_points = (HPD - (teams-1)*HA_points)/teams

sum AB_godif HA_godif H_godif HGD AGD AB_win HA_win H_win HWD AWD AB_points HA_points H_points HPD APD

sum 

save seasonalHAEngland.dta, replace

********************************************PART 2: ANALYSIS AT SEASONAL LEVEL*****************************************

******Is home advantage correlated with time, division or attendance?

xtset id year

**Promoted/relegated
gen lagrel=(division>L.division)
gen lagprom=(division<L.division)
replace lagprom=1 if L.division==. & year!=1974
replace lagprom=0 if lagprom==.
replace lagrel=0 if lagrel==.

**new stadium
gen lagnewstad1=L.newstaddum
gen lagnewstad2=L2.newstaddum
gen lagnewstad3=L3.newstaddum
gen lagnewstad4=L4.newstaddum
gen newstad5y=newstaddum+lagnewstad1+lagnewstad2+lagnewstad3+lagnewstad4
replace newstad5y=0 if newstad5y==.

**presence in dataset and in each division

tab division, gen(divdum)

bysort id: egen club_obs=count(id)
forvalues k=1/4{
bysort id: egen club_obsdiv`k'=total(divdum`k')
}

sum club_obs*

bysort manidfe: egen man_obs=count(manidfe)
forvalues k=1/4{
bysort manidfe: egen man_obsdiv`k'=total(divdum`k')
}

sum man_obs*

label var relatt "attendance"
label var AP "art pitch"
label var lagprom "promoted"
label var lagrel "relegated"
label var HA_win "HA points"
label var HA_godif "HA goal dif"

sum HA_points HA_godif AB_points AB_godif avatt relatt AP lagprom lagrel year division


****Regressions with trend to test the parameters jointly and individually:

bysort year division: egen AvHA_points=mean(HA_points)
gen RHA_points=HA_points-AvHA_points
bysort year division: egen AvHA_godif=mean(HA_godif)
gen RHA_godif=HA_godif-AvHA_godif

sum HA_points RHA_points HA_godif RHA_godif relwage

gen avhome10000=avhomeatt/10000
gen avaway10000=avawayatt/10000

* New Table 3

regress RHA_godif relatt AP lagprom lagrel i.division, robust
outreg2 using HAreg, replace excel slow(1000) keep(relatt AP lagprom lagrel relwage) label less(2)

xtreg RHA_godif relatt AP lagprom lagrel i.division, fe robust
outreg2 using HAreg, append excel slow(1000) keep(relatt AP lagprom lagrel relwage) label  less(2)

regress RHA_godif relatt AP lagprom lagrel relwage i.division, robust
outreg2 using HAreg, append excel slow(1000) keep(relatt AP lagprom lagrel relwage) label  less(2)

xtreg RHA_godif relatt AP lagprom lagrel relwage i.division, fe robust
outreg2 using HAreg, append excel slow(1000) keep(relatt AP lagprom lagrel relwage) label  less(2)

regress RHA_points relatt AP lagprom lagrel i.division, robust
outreg2 using HAreg, append excel slow(1000) keep(relatt AP lagprom lagrel relwage) label  less(2)

xtreg RHA_points relatt AP lagprom lagrel i.division, fe robust
outreg2 using HAreg, append excel slow(1000) keep(relatt AP lagprom lagrel relwage) label  less(2)

regress RHA_points relatt AP lagprom lagrel relwage i.division, robust
outreg2 using HAreg, append excel slow(1000) keep(relatt AP lagprom lagrel relwage) label  less(2)

xtreg RHA_points relatt AP lagprom lagrel relwage i.division, fe robust
outreg2 using HAreg, append excel slow(1000) keep(relatt AP lagprom lagrel relwage) label  less(2)


* New Table 4

regress AB_godif relwage  AP lagprom lagrel i.division, robust
outreg2 using Qualityreg, replace excel slow(1000) keep(relwage AP lagprom lagrel) label less(1)

xtreg AB_godif relwage AP lagprom lagrel  i.division, fe robust
outreg2 using Qualityreg, append excel slow(1000) keep(relwage AP lagprom lagrel) label less(1)

regress AB_points relwage  AP lagprom lagrel i.division, robust
outreg2 using Qualityreg, append excel slow(1000) keep(relwage AP lagprom lagrel) label less(1)

xtreg AB_points relwage AP lagprom lagrel  i.division, fe robust
outreg2 using Qualityreg, append excel slow(1000) keep(relwage AP lagprom lagrel) label less(1)

* Predict residuals
reg HA_points relatt AP lagprom lagrel i.division i.year i.id
predict residHA_points, residual

*Test and read out coefficients
gen cons_points=_b[_cons]

testparm i.id
gen clubHA_points=.
gen clubHA_points_se=.
forvalues o=1/114{
replace clubHA_points=_b[`o'.id] 		if id==`o'
replace clubHA_points_se=_se[`o'.id] 	if id==`o'
}

testparm i.year
gen yearHA_points=.
gen yearHA_points_se=.
forvalues o=1974/2018{
replace yearHA_points=_b[`o'.year] 		if year==`o'
replace yearHA_points_se=_se[`o'.year] 	if year==`o'
}

reg HA_godif relatt AP lagprom lagrel i.division i.year i.id
predict residHA_godif, residual

*Test and read out coefficients
gen cons_godif=_b[_cons]

testparm i.id
gen clubHA_godif=.
gen clubHA_godif_se=.
forvalues o=1/114{
replace clubHA_godif=_b[`o'.id] 		if id==`o'
replace clubHA_godif_se=_se[`o'.id] 	if id==`o'
}

testparm i.year
gen yearHA_godif=.
gen yearHA_godif_se=.
forvalues o=1974/2018{
replace yearHA_godif=_b[`o'.year] 		if year==`o'
replace yearHA_godif_se=_se[`o'.year] 	if year==`o'
}


********************************************** PART 3: Show some graphs and tables***************************************

for var HA_win HA_points HA_godif avatt logwage: bysort year division: egen mdyX=mean(X)


****Look at division-year level
preserve

forvalues k=1/4{
for var HA_win HA_points HA_godif avatt logwage: gen X_div`k' = mdyX if division==`k'
}

collapse HA_win_div* HA_points_div* HA_godif_div* HA_win HA_points HA_godif logwage* avatt* yearHA_godif* yearHA_points*, by(division year)

forvalues k=1/4{
line HA_points_div`k' HA_godif_div`k' year, ytitle("Home advantage") xtitle("Year") legend(label(1 "Points") label(2 "Goal difference")) ysc(r(0)) lpattern(solid longdash)  graphregion(color(white))
graph save HA-div`k'.gph, replace
graph export HA-div`k'.png, replace
table year if division==`k', c(mean HA_win mean HA_points mean HA_godif mean logwage mean avatt)
}

table division, c(mean HA_win mean HA_points mean HA_godif mean logwage mean avatt)

****look at year level

collapse HA_points_div* HA_godif_div* logwage* avatt* yearHA_godif* yearHA_points*, by(year)

egen myearHA_points=mean(yearHA_points)
egen myearHA_godif=mean(yearHA_godif)
replace yearHA_points=yearHA_points-myearHA_points
replace yearHA_godif=yearHA_godif-myearHA_godif

line avatt_div* year, ytitle("Average Attendance")  xtitle("Year") legend(label(1 "Premier League") label(2 "Championship") label(3 "League One") label(4 "League Two")) ysc(r(0)) graphregion(color(white))
graph save Attendance.gph, replace
graph export Attendance.png, replace

line yearHA_godif yearHA_points year, title(Demeaned year fixed effects in home advantage) legend(label(1 "Goal difference") label(2 "Points")) ysc(r(0)) graphregion(color(white))
graph save HAyearfe.gph, replace

line HA_points_div* year, title(Average home advantage in points) legend(label(1 "Premier League") label(2 "Championship") label(3 "League One") label(4 "League Two"))
graph save HApointbydiv.gph, replace

line HA_godif_div* year, title(Average home advantage in goal dif.) legend(label(1 "Premier League") label(2 "Championship") label(3 "League One") label(4 "League Two"))
graph save HAgodifbydiv.gph, replace

restore

***look at team level
preserve
collapse HA_points* HA_godif* logwage avatt clubHA_godif* clubHA_points* id club_obs* cons*, by(team)

egen mclubHA_points=mean(clubHA_points)
egen mclubHA_godif=mean(clubHA_godif)
egen mHA_points=mean(HA_points)
egen mHA_godif=mean(HA_godif)

replace clubHA_points=clubHA_points-mclubHA_points
replace clubHA_godif=clubHA_godif-mclubHA_godif

xtable team if club_obs==45, c(mean HA_points mean clubHA_points mean HA_godif mean clubHA_godif mean avatt) filename(clubtable1) replace
xtable team if club_obs==45, c(mean club_obsdiv1 mean club_obsdiv2 mean club_obsdiv3 mean club_obsdiv4 mean HA_godif) filename(clubtable2) replace

restore

***look at manager level
preserve

reg HA_points i.year i.division
predict HA_point_pred
replace HA_points=HA_points-HA_point_pred

reg HA_godif i.year i.division
predict HA_godif_pred
replace HA_godif=HA_godif-HA_godif_pred

collapse HA_points HA_godif logwage avatt manidfe man_obs* residHA*, by(manager)

egen mHA_points=mean(HA_points)
egen mHA_godif=mean(HA_godif)

replace HA_points=HA_points-mHA_points
replace HA_godif=HA_godif-mHA_godif

xtable manager if man_obs>5, c(mean man_obs mean HA_points mean HA_godif mean residHA_points mean residHA_godif) filename(mantable1) replace
xtable manager if man_obs>5, c(mean man_obsdiv1 mean man_obsdiv2 mean man_obsdiv3 mean man_obsdiv4 mean HA_godif) filename(mantable2) replace


restore

clear*

cap log close